@@ -58,9 +58,8 @@ private:
 };
 
 // Define vtkArrayDownCast implementation:
-vtkArrayDownCast_FastCastMacro(vtkTypeInt32Array)
+vtkArrayDownCast_FastCastMacro(vtkTypeInt32Array);
 
 #undef vtkTypeArrayBase
 
 #endif
-// VTK-HeaderTest-Exclude: vtkTypedArray.h.in
